@@ -264,6 +264,10 @@ class Reservation:
                     self.log(message.data.message, message.data.level)
                     continue
 
+                if isinstance(message, AssignReceivedMessage):
+                    self.log(f"Received the Message on Provision {message.data.provision}", LogLevel.INFO)
+                    continue
+
                 if isinstance(message, AssignCriticalMessage):
                     if raise_node_exceptions:
                         raise AssignmentException(message.data.message)
@@ -328,6 +332,10 @@ class Reservation:
                 elif isinstance(message, AssignLogMessage):
                     self.log(message.data.message, message.data.level)
 
+                elif isinstance(message, AssignReceivedMessage):
+                    self.log(f"Received the Message on Provision {message.data.provision}", LogLevel.INFO)
+                    continue
+                
                 elif isinstance(message, AssignCriticalMessage):
                     raise AssignmentException(message.data.message)
 
